@@ -4,12 +4,11 @@ use warnings;
 use utf8;
 
 package Git::Wrapper::Plus::Support;
-BEGIN {
-  $Git::Wrapper::Plus::Support::AUTHORITY = 'cpan:KENTNL';
-}
-$Git::Wrapper::Plus::Support::VERSION = '0.003100';
+$Git::Wrapper::Plus::Support::VERSION = '0.003101';
 # ABSTRACT: Determine what versions of things support what
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 use Moo qw( has );
 
 
@@ -179,6 +178,14 @@ sub supports_command {
 
 
 
+
+
+
+
+
+
+
+
 
 
 
@@ -256,7 +263,7 @@ Git::Wrapper::Plus::Support - Determine what versions of things support what
 
 =head1 VERSION
 
-version 0.003100
+version 0.003101
 
 =head1 SYNOPSIS
 
@@ -292,7 +299,7 @@ to the map yet ), C<0> if it is not supported, and C<1> if it is.
 
 B<Currently indexed commands>
 
-    for-each-ref init init-db
+    for-each-ref init init-db update-cache update-index ls-remote cat-file show-diff write-tree commit-tree
 
 =head2 C<supports_behavior>
 
@@ -328,6 +335,14 @@ To update content.
 
 Not all versions of Git can checkout a detached head.
 
+=head4 C<2-arg-cat-file>
+
+The syntax:
+
+    git cat-file <type> <commitish>
+
+Should be supported everywhere that matters ( since 0.99 ), but it was not always git syntax.
+
 =head1 AUTHOR
 
 Kent Fredric <kentfredric@gmail.com>
