@@ -4,12 +4,11 @@ use warnings;
 use utf8;
 
 package Git::Wrapper::Plus::Tags;
-BEGIN {
-  $Git::Wrapper::Plus::Tags::AUTHORITY = 'cpan:KENTNL';
-}
-$Git::Wrapper::Plus::Tags::VERSION = '0.003100';
+$Git::Wrapper::Plus::Tags::VERSION = '0.003101';
 # ABSTRACT: Extract all tags from a repository
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 
 
 
@@ -226,7 +225,7 @@ Git::Wrapper::Plus::Tags - Extract all tags from a repository
 
 =head1 VERSION
 
-version 0.003100
+version 0.003101
 
 =head1 SYNOPSIS
 
