@@ -4,12 +4,11 @@ use warnings;
 use utf8;
 
 package Git::Wrapper::Plus::Tester;
-BEGIN {
-  $Git::Wrapper::Plus::Tester::AUTHORITY = 'cpan:KENTNL';
-}
-$Git::Wrapper::Plus::Tester::VERSION = '0.003100';
+$Git::Wrapper::Plus::Tester::VERSION = '0.003101';
 # ABSTRACT: Utility for testing things with a git repository
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 use Moo qw( has );
 use Path::Tiny qw(path);
 
@@ -191,7 +190,7 @@ Git::Wrapper::Plus::Tester - Utility for testing things with a git repository
 
 =head1 VERSION
 
-version 0.003100
+version 0.003101
 
 =head1 SYNOPSIS
 
