@@ -4,12 +4,11 @@ use warnings;
 use utf8;
 
 package Git::Wrapper::Plus::Versions;
-BEGIN {
-  $Git::Wrapper::Plus::Versions::AUTHORITY = 'cpan:KENTNL';
-}
-$Git::Wrapper::Plus::Versions::VERSION = '0.003100';
+$Git::Wrapper::Plus::Versions::VERSION = '0.003101';
 # ABSTRACT: Analyze and compare git versions
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 
 
 
@@ -110,7 +109,7 @@ Git::Wrapper::Plus::Versions - Analyze and compare git versions
 
 =head1 VERSION
 
-version 0.003100
+version 0.003101
 
 =head1 SYNOPSIS
 
